**Example 1: 删除快照**

删除指定快照

Input: 

```
tccli cbs DeleteSnapshots --cli-unfold-argument  \
    --SnapshotIds snap-cgrmci8t
```

Output: 
```
{
    "Response": {
        "RequestId": "b4770576-d9eb-4689-0866-5a1f8200a722"
    }
}
```

